Native interface to the TrackForgex library.
Do not use this module directly, use the TrackForgex.Trackers.ByteTrack module instead.
Native interface to the TrackForgex library.
Do not use this module directly, use the TrackForgex.Trackers.ByteTrack module instead.